@@ -112,10 +112,10 @@ module.exports = generators.Base.extend({
       this.sourceRoot(path.join(__dirname, '../templates/'));
       this.directory('common/root', '.', true);
       // create module.js
-      var moduleFile = this.readFileAsString(path.join(__dirname, 'scripts/module.js'))
+      var moduleFile = this.readFileAsString(path.join(__dirname, '../templates/scripts/module.js'))
       moduleFile = moduleFile.replace(new RegExp("{{APP_NAME}}", 'g'), this.appName);
       var moduleFilePath = this.jsPath + 'modules.js'
-      this.write(ctrlFilePath, moduleFile);
+      this.write(moduleFilePath, moduleFile);
       this.scriptsFile.push(moduleFilePath);
     },
 
