@@ -574,32 +574,6 @@ module.exports = function (grunt) {
     'newer:copy:tmp'
   ]);
 
-  grunt.registerTask('installFacebook', [
-    'addFacebookPlugin'
-  ]);
-  grunt.registerTask('installProdPlugins', [
-    'installPluginsWithVariable::local_plugins/com.viceversa.parsePushNotifications/:--variable APP_ID=ESsMZDBvfN58FPvSo2RMivqCJxljWKR1cCfn7LPa --variable CLIENT_ID=EgVqBkuBVOI3j3eqUvZldh4oFJ6fdAB8kF3udwIX',
-    'installPluginsWithVariable::local_plugins/com.viceversa.flurryLib/:--variable FLURRY_ID=6ZF84TDQRRPVGW4D8592'
-  ]);  
-  grunt.registerTask('installDevPlugins', [
-    'installPluginsWithVariable::local_plugins/com.viceversa.parsePushNotifications/:--variable APP_ID=40mMMFv2yRywJKcTAslMhj7t7sLdLarf29nDj6oW --variable CLIENT_ID=D9BLKfsDYUDxbQleZkrjiyFsxh3IuAjpqSw3qn11',
-    'installPluginsWithVariable::local_plugins/com.viceversa.flurryLib/:--variable FLURRY_ID=37P48KXXVYSPRSWY98DC'
-  ]);
-  grunt.registerTask('reinstallFacebook', [
-    'removePlugin:com.phonegap.plugins.facebookconnect',
-    'installFacebook'
-  ]);
-  grunt.registerTask('reinstallProdPlugins', [
-    'removePlugin:com.viceversa.parsePushNotifications',
-    'removePlugin:com.viceversa.flurryLib',
-    'installProdPlugins'
-  ]);  
-  grunt.registerTask('reinstallDevPlugins', [
-    'removePlugin:com.viceversa.parsePushNotifications',
-    'removePlugin:com.viceversa.flurryLib',
-    'installDevPlugins'
-  ]);
-
   grunt.registerTask('compress', function() {
     return grunt.task.run([
       'clean',
@@ -669,33 +643,6 @@ module.exports = function (grunt) {
     }
   });
 
-  grunt.registerTask('installFacebook', [
-    'addFacebookPlugin'
-  ]);
-  grunt.registerTask('installProdPlugins', [
-    'installPluginsWithVariable::local_plugins/com.viceversa.parsePushNotifications/:--variable APP_ID=ESsMZDBvfN58FPvSo2RMivqCJxljWKR1cCfn7LPa --variable CLIENT_ID=EgVqBkuBVOI3j3eqUvZldh4oFJ6fdAB8kF3udwIX',
-    'installPluginsWithVariable::local_plugins/com.viceversa.flurryLib/:--variable FLURRY_ID=6ZF84TDQRRPVGW4D8592'
-  ]);  
-  grunt.registerTask('installDevPlugins', [
-    'installPluginsWithVariable::local_plugins/com.viceversa.parsePushNotifications/:--variable APP_ID=40mMMFv2yRywJKcTAslMhj7t7sLdLarf29nDj6oW --variable CLIENT_ID=D9BLKfsDYUDxbQleZkrjiyFsxh3IuAjpqSw3qn11',
-    'installPluginsWithVariable::local_plugins/com.viceversa.flurryLib/:--variable FLURRY_ID=37P48KXXVYSPRSWY98DC'
-  ]);
-  grunt.registerTask('reinstallFacebook', [
-    'removePlugin:com.phonegap.plugins.facebookconnect',
-    'installFacebook'
-  ]);
-  grunt.registerTask('reinstallProdPlugins', [
-    'removePlugin:com.viceversa.parsePushNotifications',
-    'removePlugin:com.viceversa.flurryLib',
-    'installProdPlugins'
-  ]);  
-  grunt.registerTask('reinstallDevPlugins', [
-    'removePlugin:com.viceversa.parsePushNotifications',
-    'removePlugin:com.viceversa.flurryLib',
-    'installDevPlugins'
-  ]);
-
-
   grunt.registerTask('coverage', 
     ['karma:continuous',
     'connect:coverage:keepalive'
