@@ -1,5 +1,5 @@
 'use strict';
-angular.module('{{APP_NAME}}.services').factory('TwitterService', [
+angular.module('{{APP_NAME}}.services').factory('TwitterAuthService', [
   '$q',
   '$cordovaSocialSharing',
   '$ionicPlatform',
