@@ -1,5 +1,6 @@
 
-var async = require('async');
+var path      = require('path');
+var async     = require('async');
 
 var flurryIdPrompt = [
   {
@@ -84,7 +85,7 @@ module.exports = {
   install: function(self) {
     if (self.grunt) {
       var done = self.async();
-      var gruntfile = self.readFileAsString(path.join(__dirname, '../common/_Gruntfile.js'))
+      var gruntfile = self.readFileAsString(path.join(__dirname, '../templates/common/_Gruntfile.js'))
       var removePlugins = '';
       var installPluginsDev = '';
       var installPluginsProd = '';
@@ -93,9 +94,9 @@ module.exports = {
         function askForFlurryIds(next) {
           if (self.flurry) {
             self.prompt(flurryIdPrompt, function (props) {
-              installPluginsDev += 'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.flurryLib/:--variable FLURRY_ID=' + props.FLURRY_ID_DEV;
-              installPluginsProd += 'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.flurryLib/:--variable FLURRY_ID=' + props.FLURRY_ID_PROD;
-              removePlugins += "\'removePlugin:com.{{APP_NAME}}.flurryLib',\n";
+              installPluginsDev += "'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.flurryLib/:--variable FLURRY_ID=" + props.FLURRY_ID_DEV + "'\,\n";
+              installPluginsProd += "'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.flurryLib/:--variable FLURRY_ID=" + props.FLURRY_ID_PROD + "'\,\n";
+              removePlugins += "\'removePlugin:com.{{APP_NAME}}.flurryLib\',\n";
               next();
             }.bind(self));
           } else {
@@ -105,9 +106,9 @@ module.exports = {
         function askForParseIds(next) {
           if (self.push) {
             self.prompt(parseIdPrompt, function (props) {
-              installPluginsDev += 'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.parsePushNotifications/:--variable APP_ID=' + props.PARSE_APP_DEV_ID + ' --variable CLIENT_ID=' + props.PARSE_CLIENT_DEV_ID + '\',';
-              installPluginsProd += 'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.parsePushNotifications/:--variable APP_ID=' + props.PARSE_APP_PROD_ID + ' --variable CLIENT_ID=' + props.PARSE_CLIENT_PROD_ID + '\',';
-              removePlugins += "\'removePlugin:com.{{APP_NAME}}.parsePushNotifications',\n";
+              installPluginsDev += "'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.parsePushNotifications/:--variable APP_ID=" + props.PARSE_APP_DEV_ID + " --variable CLIENT_ID=" + props.PARSE_CLIENT_DEV_ID + "\',\n";
+              installPluginsProd += "'installPluginsWithVariable::local_plugins/com.{{APP_NAME}}.parsePushNotifications/:--variable APP_ID=" + props.PARSE_APP_PROD_ID + " --variable CLIENT_ID=" + props.PARSE_CLIENT_PROD_ID + "\',\n";
+              removePlugins += "\'removePlugin:com.{{APP_NAME}}.parsePushNotifications\',\n";
               next();
             }.bind(self));
           } else {
@@ -117,18 +118,21 @@ module.exports = {
         function askForFacebookIds(next) {
           if (self.facebook) {
             self.prompt(parseIdPrompt, function (props) {
-              installPluginsDev += "installPluginsWithVariable:1:github.com/phonegap/phonegap-facebook-plugin.git --variable APP_ID=" + props.FACEBOOK_APP_ID_DEV + " --variable APP_NAME=" + props.FACEBOOK_APP_NAME_DEV + ";";
-              installPluginsProd += "installPluginsWithVariable:1:github.com/phonegap/phonegap-facebook-plugin.git --variable APP_ID=" + props.FACEBOOK_APP_ID_PROD + " --variable APP_NAME=" + props.FACEBOOK_APP_NAME_PROD + ";";
-              removePlugins += "\'removePlugin:com.phonegap.plugins.facebookconnect',\n"  
+              installPluginsDev += "'installPluginsWithVariable:1:github.com/phonegap/phonegap-facebook-plugin.git --variable APP_ID=" + props.FACEBOOK_APP_ID_DEV + " --variable APP_NAME=" + props.FACEBOOK_APP_NAME_DEV + "'\n";
+              installPluginsProd += "'installPluginsWithVariable:1:github.com/phonegap/phonegap-facebook-plugin.git --variable APP_ID=" + props.FACEBOOK_APP_ID_PROD + " --variable APP_NAME=" + props.FACEBOOK_APP_NAME_PROD + "'\n";
+              removePlugins += "\'removePlugin:com.phonegap.plugins.facebookconnect\'\n"  
               next();
             }.bind(self));
           } else {
             next();
           }
         }
-      ]).then(function() {
+      ], function() {
         gruntfile = gruntfile.replace(new RegExp("{{APP_NAME}}", 'g'), self.appName);
-        self.write('Gruntfile.js', file);
+        gruntfile = gruntfile.replace(new RegExp("{{PLUGINS_DEV}}", 'g'), installPluginsDev);
+        gruntfile = gruntfile.replace(new RegExp("{{PLUGINS_PROD}}", 'g'), installPluginsProd);
+        gruntfile = gruntfile.replace(new RegExp("{{REMOVE_PLUGINS}}", 'g'), removePlugins);
+        self.write('Gruntfile.js', gruntfile);
         done();
       });
     }
