@@ -9,7 +9,8 @@ module.exports = {
   routes: require('./routes.js'),
   push: require('./push.js'),
   analytics: require('./analytics.js'),
-  models: require('./models.js')
+  models: require('./models.js'),
+  grunt: require('./gruntfile.js')
 };
 
 function mergeCollections(arr1, arr2, prop) {
